import QtQuick
import QtQuick.Window
import QtQuick3D
import QtQuick3D.Helpers 1.0
import QtQuick.Layouts

Window
{
    id: window
    width: 1920
    height: 1080
    visible: true
    title: qsTr("tk:dlg:programtitle")
    color: "black"

    Node
    {
        id: sceneRoot
        Node
        {
            id: sceneRootNode

            Node
            {
                Node
                {
                    id: reflectionScene

                    Component.onCompleted:
                    {
                        ModelController.setRootNode(this);
                    }
                }
            }
        }

        DirectionalLight
        {
            color: Qt.rgba(1.0, 1.0, 1.0, 1.0)
            position: Qt.vector3d(0, 300, 0)
            castsShadow: true
            brightness: 2.0
            eulerRotation: Qt.vector3d(-45, 20, 0)
            visible: true
        }

        PerspectiveCamera
        {
            id: mainCamera
            position.z: 30.0
            position.y: 30.0
            eulerRotation: Qt.vector3d(-40, -10, 0)
            clipFar: 5000
            clipNear: 1
        }

        Model
        {
            id: testNode
            source: "#Cube"
            scale: Qt.vector3d(0.01, 0.01, 0.01)
            materials: [
                DefaultMaterial {
                    diffuseColor: Qt.rgba(1.0, 0.9, 0.7, 1.0)
                }
            ]
        }
    }

    Item
    {
        width: parent.width
        height: parent.height

        View3D
        {
            anchors.fill: parent
            id: view
            camera: mainCamera
            importScene: sceneRoot
            environment: SceneEnvironment
            {
                clearColor: window.color
                antialiasingMode: SceneEnvironment.SSAA
                antialiasingQuality: SceneEnvironment.VeryHigh
                backgroundMode: SceneEnvironment.SkyBox
                lightProbe: Texture
                {
                    source: "qrc:/probes/day.hdr"
                    mappingMode: Texture.LightProbe
                }
                probeExposure: 1.5
            }

            Model
            {
                source: "#Rectangle"
                castsShadows: true
                receivesShadows: true
                scale: Qt.vector3d(10, 10, 10)
                position: parent.position
                eulerRotation: Qt.vector3d(-90, 0, 0)
                materials:
                [
                    groundMaterial
                ]

                CustomMaterial
                {
                    id: groundMaterial
                    shadingMode: CustomMaterial.Shaded
                    vertexShader: "qrc:/ground.vert"
                    fragmentShader: "qrc:/ground.frag"
                    sourceBlend: CustomMaterial.SrcAlpha
                    destinationBlend: CustomMaterial.OneMinusSrcAlpha
                }
            }
        }

    }
    Rectangle
    {
        width: 30
        height: 40
        color: "red"
        MouseArea
        {
            anchors.fill: parent
            onClicked:
            {
                ModelController.loadModel();
                testNode.parent = reflectionScene;
            }
        }
    }
}
